@@ -1,5 +1,5 @@
 from airflow.plugins_manager import AirflowPlugin
-from odd_airflow_integration import listener
+from dir import listener
 
 
 class OddPlugin(AirflowPlugin):
